import 'package:flutter/cupertino.dart';
import 'package:go_router/go_router.dart';

abstract class AppRouter {
  /// Default transition for all pages
  static Page<void> defaultTransition(
    BuildContext context,
    GoRouterState state,
    Widget child,
  ) =>
      CupertinoPage<void>(
        key: state.pageKey,
        child: child,
      );

  /// Disable transition animation
  static Page<void> noTransition(
    BuildContext context,
    GoRouterState state,
    Widget child,
  ) =>
      CustomTransitionPage<void>(
        key: state.pageKey,
        transitionsBuilder: (_, __, ___, child) => child,
        child: child,
      );

  /// Defines public routes (no authentication needed).
  /// 
  /// Example:
  /// ```dart
  /// static final publicRoutes = [
  /// '/',
  /// '/sign_in',
  /// '/sign_up',
  /// ];
  /// ```
  static final List<String> publicRoutes = [];

  /// Defines GoRoute routes.
  static final List<GoRoute> routes = [];
}
